@@ -268,7 +268,7 @@
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="86"/>
-        <location filename="../mainwindow.cpp" line="267"/>
+        <location filename="../mainwindow.cpp" line="268"/>
         <location filename="../mainwindow.cpp" line="392"/>
         <source>Failure</source>
         <translation type="unfinished"></translation>
@@ -286,17 +286,17 @@ Please wait until the the process is completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="265"/>
+        <location filename="../mainwindow.cpp" line="266"/>
         <source>Success</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="265"/>
+        <location filename="../mainwindow.cpp" line="266"/>
         <source>LiveUSB creation successful!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="267"/>
+        <location filename="../mainwindow.cpp" line="268"/>
         <source>Error encountered in the LiveUSB creation process</source>
         <translation type="unfinished"></translation>
     </message>
@@ -317,13 +317,8 @@ Please wait until the the process is completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="360"/>
-        <source>%1 License</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="368"/>
-        <source>%1 Help</source>
+        <location filename="../mainwindow.cpp" line="355"/>
+        <source>About %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -331,11 +326,6 @@ Please wait until the the process is completed</source>
         <source>Version: </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="355"/>
-        <source>About %1</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="357"/>
         <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
@@ -347,8 +337,14 @@ Please wait until the the process is completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Cancel</source>
-        <translation type="vanished">Loobu</translation>
+        <location filename="../mainwindow.cpp" line="360"/>
+        <source>%1 License</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="368"/>
+        <source>%1 Help</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="379"/>
@@ -386,11 +382,6 @@ Please wait until the the process is completed</source>
 </context>
 <context>
     <name>QApplication</name>
-    <message>
-        <location filename="../main.cpp" line="75"/>
-        <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../about.cpp" line="32"/>
         <source>License</source>
@@ -405,12 +396,17 @@ Please wait until the the process is completed</source>
     <message>
         <location filename="../about.cpp" line="34"/>
         <source>Cancel</source>
-        <translation type="unfinished">Loobu</translation>
+        <translation>Loobu</translation>
     </message>
     <message>
         <location filename="../about.cpp" line="51"/>
         <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../main.cpp" line="75"/>
+        <source>You must run this program as root.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
